==> haskell-regex-applicative-text-0.1.0.1-312.1-loong64.pkg.tar.zst: usr/share/haskell/register/haskell-regex-applicative-text.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
printf '%s' 'name:                 regex-applicative-text
version:              0.1.0.1
visibility:           public
id:                   regex-applicative-text-0.1.0.1-IB6wZg9ls6C8C8zaV1YIZh
key:                  regex-applicative-text-0.1.0.1-IB6wZg9ls6C8C8zaV1YIZh
license:              BSD-3-Clause
maintainer:           Oleg Grenrus <oleg.grenrus@iki.fi>
author:               Oleg Grenrus <oleg.grenrus@iki.fi>
homepage:             https://github.com/phadej/regex-applicative-text#readme
synopsis:             regex-applicative on text
description:          Wrapped regex-applicative primitives to work with Text
category:             Text
abi:                  e88d07f7ecafac5a8161b1e3ad84674c
exposed:              True
exposed-modules:      Text.Regex.Applicative.Text
import-dirs:
    /usr/lib/ghc-9.6.6/site-local/regex-applicative-text-0.1.0.1

library-dirs:
    /usr/lib/ghc-9.6.6/site-local/regex-applicative-text-0.1.0.1

library-dirs-static:
    /usr/lib/ghc-9.6.6/site-local/regex-applicative-text-0.1.0.1

dynamic-library-dirs: /usr/lib
data-dir:             /usr/share/haskell-regex-applicative-text
hs-libraries:         HSregex-applicative-text-0.1.0.1-IB6wZg9ls6C8C8zaV1YIZh
depends:
    base-4.18.2.1 regex-applicative-0.3.4-IOg9SG4NfoV1BVfdLhHuSS
    text-2.0.2

haddock-interfaces:
    /usr/share/doc/haskell-regex-applicative-text/html/regex-applicative-text.haddock

haddock-html:         /usr/share/doc/haskell-regex-applicative-text/html
' | '/usr/bin/ghc-pkg-9.6.6' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"

==> haskell-regex-applicative-text-0.1.0.1-313-loong64.pkg.tar.zst: usr/share/haskell/register/haskell-regex-applicative-text.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
printf '%s' 'name:                 regex-applicative-text
version:              0.1.0.1
visibility:           public
id:                   regex-applicative-text-0.1.0.1-883ENyLt4CSC7gRSXOsPPk
key:                  regex-applicative-text-0.1.0.1-883ENyLt4CSC7gRSXOsPPk
license:              BSD-3-Clause
maintainer:           Oleg Grenrus <oleg.grenrus@iki.fi>
author:               Oleg Grenrus <oleg.grenrus@iki.fi>
homepage:             https://github.com/phadej/regex-applicative-text#readme
synopsis:             regex-applicative on text
description:          Wrapped regex-applicative primitives to work with Text
category:             Text
abi:                  6625c51d8090f808d8e839b58cfe57fb
exposed:              True
exposed-modules:      Text.Regex.Applicative.Text
import-dirs:
    /usr/lib/ghc-9.6.6/site-local/regex-applicative-text-0.1.0.1

library-dirs:
    /usr/lib/ghc-9.6.6/site-local/regex-applicative-text-0.1.0.1

library-dirs-static:
    /usr/lib/ghc-9.6.6/site-local/regex-applicative-text-0.1.0.1

dynamic-library-dirs: /usr/lib
data-dir:             /usr/share/haskell-regex-applicative-text
hs-libraries:         HSregex-applicative-text-0.1.0.1-883ENyLt4CSC7gRSXOsPPk
depends:
    base-4.18.2.1 regex-applicative-0.3.4-4QdTBqQAZ4mDJnVX7OUMhV
    text-2.0.2

haddock-interfaces:
    /usr/share/doc/haskell-regex-applicative-text/html/regex-applicative-text.haddock

haddock-html:         /usr/share/doc/haskell-regex-applicative-text/html
' | '/usr/bin/ghc-pkg-9.6.6' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"
